/****************************************************************************
** Meta object code from reading C++ file 'TextViewerItem.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../mauikit-documents-4.0.2/src/code/cbz/code/TextViewerItem.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'TextViewerItem.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14TextViewerItemE_t {};
} // unnamed namespace

template <> constexpr inline auto TextViewerItem::qt_create_metaobjectdata<qt_meta_tag_ZN14TextViewerItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TextViewerItem",
        "paragraphsChanged",
        "",
        "shapeChanged",
        "shapeOffsetChanged",
        "shapeMultiplierChanged",
        "styleChanged",
        "fontFamilyChanged",
        "linkRectsChanged",
        "hoveredLinkChanged",
        "linkHovered",
        "link",
        "linkActivated",
        "paragraphs",
        "shape",
        "QVariantList",
        "shapeOffset",
        "QPoint",
        "shapeMultiplier",
        "style",
        "fontFamily",
        "linkRects",
        "hoveredLink"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'paragraphsChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'shapeChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'shapeOffsetChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'shapeMultiplierChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'styleChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fontFamilyChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'linkRectsChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hoveredLinkChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'linkHovered'
        QtMocHelpers::SignalData<void(const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Signal 'linkActivated'
        QtMocHelpers::SignalData<void(const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'paragraphs'
        QtMocHelpers::PropertyData<QStringList>(13, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'shape'
        QtMocHelpers::PropertyData<QVariantList>(14, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'shapeOffset'
        QtMocHelpers::PropertyData<QPoint>(16, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'shapeMultiplier'
        QtMocHelpers::PropertyData<double>(18, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'style'
        QtMocHelpers::PropertyData<QObject*>(19, QMetaType::QObjectStar, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'fontFamily'
        QtMocHelpers::PropertyData<QString>(20, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'linkRects'
        QtMocHelpers::PropertyData<QVariantList>(21, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 6),
        // property 'hoveredLink'
        QtMocHelpers::PropertyData<QString>(22, QMetaType::QString, QMC::DefaultPropertyFlags, 7),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TextViewerItem, qt_meta_tag_ZN14TextViewerItemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TextViewerItem::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14TextViewerItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14TextViewerItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14TextViewerItemE_t>.metaTypes,
    nullptr
} };

void TextViewerItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TextViewerItem *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->paragraphsChanged(); break;
        case 1: _t->shapeChanged(); break;
        case 2: _t->shapeOffsetChanged(); break;
        case 3: _t->shapeMultiplierChanged(); break;
        case 4: _t->styleChanged(); break;
        case 5: _t->fontFamilyChanged(); break;
        case 6: _t->linkRectsChanged(); break;
        case 7: _t->hoveredLinkChanged(); break;
        case 8: _t->linkHovered((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->linkActivated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TextViewerItem::*)()>(_a, &TextViewerItem::paragraphsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TextViewerItem::*)()>(_a, &TextViewerItem::shapeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TextViewerItem::*)()>(_a, &TextViewerItem::shapeOffsetChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TextViewerItem::*)()>(_a, &TextViewerItem::shapeMultiplierChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (TextViewerItem::*)()>(_a, &TextViewerItem::styleChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (TextViewerItem::*)()>(_a, &TextViewerItem::fontFamilyChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (TextViewerItem::*)()>(_a, &TextViewerItem::linkRectsChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (TextViewerItem::*)()>(_a, &TextViewerItem::hoveredLinkChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (TextViewerItem::*)(const QString & )>(_a, &TextViewerItem::linkHovered, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (TextViewerItem::*)(const QString & )>(_a, &TextViewerItem::linkActivated, 9))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QStringList*>(_v) = _t->paragraphs(); break;
        case 1: *reinterpret_cast<QVariantList*>(_v) = _t->shape(); break;
        case 2: *reinterpret_cast<QPoint*>(_v) = _t->shapeOffset(); break;
        case 3: *reinterpret_cast<double*>(_v) = _t->shapeMultiplier(); break;
        case 4: *reinterpret_cast<QObject**>(_v) = _t->style(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->fontFamily(); break;
        case 6: *reinterpret_cast<QVariantList*>(_v) = _t->linkRects(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->hoveredLink(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setParagraphs(*reinterpret_cast<QStringList*>(_v)); break;
        case 1: _t->setShape(*reinterpret_cast<QVariantList*>(_v)); break;
        case 2: _t->setShapeOffset(*reinterpret_cast<QPoint*>(_v)); break;
        case 3: _t->setShapeMultiplier(*reinterpret_cast<double*>(_v)); break;
        case 4: _t->setStyle(*reinterpret_cast<QObject**>(_v)); break;
        case 5: _t->setFontFamily(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *TextViewerItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TextViewerItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14TextViewerItemE_t>.strings))
        return static_cast<void*>(this);
    return QQuickItem::qt_metacast(_clname);
}

int TextViewerItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void TextViewerItem::paragraphsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void TextViewerItem::shapeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void TextViewerItem::shapeOffsetChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void TextViewerItem::shapeMultiplierChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void TextViewerItem::styleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void TextViewerItem::fontFamilyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void TextViewerItem::linkRectsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void TextViewerItem::hoveredLinkChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void TextViewerItem::linkHovered(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void TextViewerItem::linkActivated(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}
QT_WARNING_POP
