/****************************************************************************
** Meta object code from reading C++ file 'AcbfTextlayer.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../../mauikit-documents-4.0.2/src/code/cbz/code/acbf/AcbfTextlayer.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'AcbfTextlayer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN23AdvancedComicBookFormat9TextlayerE_t {};
} // unnamed namespace

template <> constexpr inline auto AdvancedComicBookFormat::Textlayer::qt_create_metaobjectdata<qt_meta_tag_ZN23AdvancedComicBookFormat9TextlayerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AdvancedComicBookFormat::Textlayer",
        "languageChanged",
        "",
        "bgcolorChanged",
        "textareaAdded",
        "Textarea*",
        "newArea",
        "textareasChanged",
        "textareaPointStringsChanged",
        "textarea",
        "index",
        "textareaIndex",
        "addTextarea",
        "removeTextarea",
        "swapTextareas",
        "swapThis",
        "withThis",
        "language",
        "bgcolor",
        "textareaPointStrings",
        "textareas",
        "QObjectList"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'languageChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'bgcolorChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'textareaAdded'
        QtMocHelpers::SignalData<void(Textarea *)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'textareasChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'textareaPointStringsChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'textarea'
        QtMocHelpers::MethodData<Textarea *(int) const>(9, 2, QMC::AccessPublic, 0x80000000 | 5, {{
            { QMetaType::Int, 10 },
        }}),
        // Method 'textareaIndex'
        QtMocHelpers::MethodData<int(Textarea *) const>(11, 2, QMC::AccessPublic, QMetaType::Int, {{
            { 0x80000000 | 5, 9 },
        }}),
        // Method 'addTextarea'
        QtMocHelpers::MethodData<void(int)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 },
        }}),
        // Method 'addTextarea'
        QtMocHelpers::MethodData<void()>(12, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Method 'removeTextarea'
        QtMocHelpers::MethodData<void(int)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 },
        }}),
        // Method 'swapTextareas'
        QtMocHelpers::MethodData<bool(int, int)>(14, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 15 }, { QMetaType::Int, 16 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'language'
        QtMocHelpers::PropertyData<QString>(17, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'bgcolor'
        QtMocHelpers::PropertyData<QString>(18, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'textareaPointStrings'
        QtMocHelpers::PropertyData<QStringList>(19, QMetaType::QStringList, QMC::DefaultPropertyFlags, 4),
        // property 'textareas'
        QtMocHelpers::PropertyData<QObjectList>(20, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 3),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Textlayer, qt_meta_tag_ZN23AdvancedComicBookFormat9TextlayerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AdvancedComicBookFormat::Textlayer::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23AdvancedComicBookFormat9TextlayerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23AdvancedComicBookFormat9TextlayerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23AdvancedComicBookFormat9TextlayerE_t>.metaTypes,
    nullptr
} };

void AdvancedComicBookFormat::Textlayer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Textlayer *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->languageChanged(); break;
        case 1: _t->bgcolorChanged(); break;
        case 2: _t->textareaAdded((*reinterpret_cast<std::add_pointer_t<Textarea*>>(_a[1]))); break;
        case 3: _t->textareasChanged(); break;
        case 4: _t->textareaPointStringsChanged(); break;
        case 5: { Textarea* _r = _t->textarea((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Textarea**>(_a[0]) = std::move(_r); }  break;
        case 6: { int _r = _t->textareaIndex((*reinterpret_cast<std::add_pointer_t<Textarea*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 7: _t->addTextarea((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->addTextarea(); break;
        case 9: _t->removeTextarea((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: { bool _r = _t->swapTextareas((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Textlayer::*)()>(_a, &Textlayer::languageChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Textlayer::*)()>(_a, &Textlayer::bgcolorChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Textlayer::*)(Textarea * )>(_a, &Textlayer::textareaAdded, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Textlayer::*)()>(_a, &Textlayer::textareasChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Textlayer::*)()>(_a, &Textlayer::textareaPointStringsChanged, 4))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->language(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->bgcolor(); break;
        case 2: *reinterpret_cast<QStringList*>(_v) = _t->textareaPointStrings(); break;
        case 3: *reinterpret_cast<QObjectList*>(_v) = _t->textareas(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setLanguage(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setBgcolor(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *AdvancedComicBookFormat::Textlayer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AdvancedComicBookFormat::Textlayer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23AdvancedComicBookFormat9TextlayerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int AdvancedComicBookFormat::Textlayer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void AdvancedComicBookFormat::Textlayer::languageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void AdvancedComicBookFormat::Textlayer::bgcolorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void AdvancedComicBookFormat::Textlayer::textareaAdded(Textarea * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void AdvancedComicBookFormat::Textlayer::textareasChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void AdvancedComicBookFormat::Textlayer::textareaPointStringsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
