/****************************************************************************
** Meta object code from reading C++ file 'BookListModel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../mauikit-documents-4.0.2/src/code/cbz/code/BookListModel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'BookListModel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13BookListModelE_t {};
} // unnamed namespace

template <> constexpr inline auto BookListModel::qt_create_metaobjectdata<qt_meta_tag_ZN13BookListModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BookListModel",
        "contentModelChanged",
        "",
        "countChanged",
        "titleCategoryModelChanged",
        "newlyAddedCategoryModelChanged",
        "authorCategoryModelChanged",
        "seriesCategoryModelChanged",
        "publisherCategoryModelChanged",
        "keywordCategoryModelChanged",
        "folderCategoryModelChanged",
        "cacheLoadedChanged",
        "contentModelItemsInserted",
        "QModelIndex",
        "index",
        "first",
        "last",
        "seriesModelForEntry",
        "fileName",
        "setBookData",
        "property",
        "value",
        "removeBook",
        "deleteFile",
        "knownBookFiles",
        "count",
        "contentModel",
        "newlyAddedCategoryModel",
        "titleCategoryModel",
        "authorCategoryModel",
        "seriesCategoryModel",
        "publisherCategoryModel",
        "keywordCategoryModel",
        "folderCategoryModel",
        "cacheLoaded",
        "Grouping",
        "GroupByNone",
        "GroupByRecentlyAdded",
        "GroupByRecentlyRead",
        "GroupByTitle",
        "GroupByAuthor",
        "GroupByPublisher"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'contentModelChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'countChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'titleCategoryModelChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'newlyAddedCategoryModelChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'authorCategoryModelChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'seriesCategoryModelChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'publisherCategoryModelChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'keywordCategoryModelChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'folderCategoryModelChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'cacheLoadedChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'contentModelItemsInserted'
        QtMocHelpers::SlotData<void(QModelIndex, int, int)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 13, 14 }, { QMetaType::Int, 15 }, { QMetaType::Int, 16 },
        }}),
        // Method 'seriesModelForEntry'
        QtMocHelpers::MethodData<QObject *(QString)>(17, 2, QMC::AccessPublic, QMetaType::QObjectStar, {{
            { QMetaType::QString, 18 },
        }}),
        // Method 'setBookData'
        QtMocHelpers::MethodData<void(QString, QString, QString)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 18 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 },
        }}),
        // Method 'removeBook'
        QtMocHelpers::MethodData<void(QString, bool)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 18 }, { QMetaType::Bool, 23 },
        }}),
        // Method 'removeBook'
        QtMocHelpers::MethodData<void(QString)>(22, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 18 },
        }}),
        // Method 'knownBookFiles'
        QtMocHelpers::MethodData<QStringList() const>(24, 2, QMC::AccessPublic, QMetaType::QStringList),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'count'
        QtMocHelpers::PropertyData<int>(25, QMetaType::Int, QMC::DefaultPropertyFlags, 1),
        // property 'contentModel'
        QtMocHelpers::PropertyData<QObject*>(26, QMetaType::QObjectStar, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'newlyAddedCategoryModel'
        QtMocHelpers::PropertyData<QObject*>(27, QMetaType::QObjectStar, QMC::DefaultPropertyFlags, 3),
        // property 'titleCategoryModel'
        QtMocHelpers::PropertyData<QObject*>(28, QMetaType::QObjectStar, QMC::DefaultPropertyFlags, 2),
        // property 'authorCategoryModel'
        QtMocHelpers::PropertyData<QObject*>(29, QMetaType::QObjectStar, QMC::DefaultPropertyFlags, 4),
        // property 'seriesCategoryModel'
        QtMocHelpers::PropertyData<QObject*>(30, QMetaType::QObjectStar, QMC::DefaultPropertyFlags, 5),
        // property 'publisherCategoryModel'
        QtMocHelpers::PropertyData<QObject*>(31, QMetaType::QObjectStar, QMC::DefaultPropertyFlags, 6),
        // property 'keywordCategoryModel'
        QtMocHelpers::PropertyData<QObject*>(32, QMetaType::QObjectStar, QMC::DefaultPropertyFlags, 7),
        // property 'folderCategoryModel'
        QtMocHelpers::PropertyData<QObject*>(33, QMetaType::QObjectStar, QMC::DefaultPropertyFlags, 8),
        // property 'cacheLoaded'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags, 9),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Grouping'
        QtMocHelpers::EnumData<enum Grouping>(35, 35, QMC::EnumFlags{}).add({
            {   36, Grouping::GroupByNone },
            {   37, Grouping::GroupByRecentlyAdded },
            {   38, Grouping::GroupByRecentlyRead },
            {   39, Grouping::GroupByTitle },
            {   40, Grouping::GroupByAuthor },
            {   41, Grouping::GroupByPublisher },
        }),
    };
    return QtMocHelpers::metaObjectData<BookListModel, qt_meta_tag_ZN13BookListModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject BookListModel::staticMetaObject = { {
    QMetaObject::SuperData::link<CategoryEntriesModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13BookListModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13BookListModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13BookListModelE_t>.metaTypes,
    nullptr
} };

void BookListModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BookListModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->contentModelChanged(); break;
        case 1: _t->countChanged(); break;
        case 2: _t->titleCategoryModelChanged(); break;
        case 3: _t->newlyAddedCategoryModelChanged(); break;
        case 4: _t->authorCategoryModelChanged(); break;
        case 5: _t->seriesCategoryModelChanged(); break;
        case 6: _t->publisherCategoryModelChanged(); break;
        case 7: _t->keywordCategoryModelChanged(); break;
        case 8: _t->folderCategoryModelChanged(); break;
        case 9: _t->cacheLoadedChanged(); break;
        case 10: _t->contentModelItemsInserted((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 11: { QObject* _r = _t->seriesModelForEntry((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QObject**>(_a[0]) = std::move(_r); }  break;
        case 12: _t->setBookData((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 13: _t->removeBook((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 14: _t->removeBook((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 15: { QStringList _r = _t->knownBookFiles();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (BookListModel::*)()>(_a, &BookListModel::contentModelChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (BookListModel::*)()>(_a, &BookListModel::countChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (BookListModel::*)()>(_a, &BookListModel::titleCategoryModelChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (BookListModel::*)()>(_a, &BookListModel::newlyAddedCategoryModelChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (BookListModel::*)()>(_a, &BookListModel::authorCategoryModelChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (BookListModel::*)()>(_a, &BookListModel::seriesCategoryModelChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (BookListModel::*)()>(_a, &BookListModel::publisherCategoryModelChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (BookListModel::*)()>(_a, &BookListModel::keywordCategoryModelChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (BookListModel::*)()>(_a, &BookListModel::folderCategoryModelChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (BookListModel::*)()>(_a, &BookListModel::cacheLoadedChanged, 9))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->count(); break;
        case 1: *reinterpret_cast<QObject**>(_v) = _t->contentModel(); break;
        case 2: *reinterpret_cast<QObject**>(_v) = _t->newlyAddedCategoryModel(); break;
        case 3: *reinterpret_cast<QObject**>(_v) = _t->titleCategoryModel(); break;
        case 4: *reinterpret_cast<QObject**>(_v) = _t->authorCategoryModel(); break;
        case 5: *reinterpret_cast<QObject**>(_v) = _t->seriesCategoryModel(); break;
        case 6: *reinterpret_cast<QObject**>(_v) = _t->publisherCategoryModel(); break;
        case 7: *reinterpret_cast<QObject**>(_v) = _t->keywordCategoryModel(); break;
        case 8: *reinterpret_cast<QObject**>(_v) = _t->folderCategoryModel(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->cacheLoaded(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setContentModel(*reinterpret_cast<QObject**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *BookListModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BookListModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13BookListModelE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return CategoryEntriesModel::qt_metacast(_clname);
}

int BookListModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = CategoryEntriesModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 16;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void BookListModel::contentModelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void BookListModel::countChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void BookListModel::titleCategoryModelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void BookListModel::newlyAddedCategoryModelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void BookListModel::authorCategoryModelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void BookListModel::seriesCategoryModelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void BookListModel::publisherCategoryModelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void BookListModel::keywordCategoryModelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void BookListModel::folderCategoryModelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void BookListModel::cacheLoadedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}
QT_WARNING_POP
