/****************************************************************************
** Meta object code from reading C++ file 'ArchiveBookModel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../mauikit-documents-4.0.2/src/code/cbz/code/ArchiveBookModel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ArchiveBookModel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16ArchiveBookModelE_t {};
} // unnamed namespace

template <> constexpr inline auto ArchiveBookModel::qt_create_metaobjectdata<qt_meta_tag_ZN16ArchiveBookModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ArchiveBookModel",
        "qmlEngineChanged",
        "",
        "readWriteChanged",
        "hasUnsavedChangesChanged",
        "fileEntriesChanged",
        "fileEntriesToDeleteChanged",
        "setDirty",
        "isDirty",
        "fileEntryReferenced",
        "fileEntry",
        "fileEntryIsDirectory",
        "markArchiveFileForDeletion",
        "archiveFile",
        "markForDeletion",
        "saveBook",
        "removePage",
        "pageNumber",
        "addPageFromFile",
        "fileUrl",
        "insertAfter",
        "swapPages",
        "swapThisIndex",
        "withThisIndex",
        "createBook",
        "folder",
        "title",
        "coverUrl",
        "previewForId",
        "id",
        "fontFamilyName",
        "fontFileName",
        "firstAvailableFont",
        "fontList",
        "qmlEngine",
        "readWrite",
        "hasUnsavedChanges",
        "fileEntries",
        "fileEntriesToDelete"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'qmlEngineChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'readWriteChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hasUnsavedChangesChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fileEntriesChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fileEntriesToDeleteChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'setDirty'
        QtMocHelpers::MethodData<void(bool)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Method 'setDirty'
        QtMocHelpers::MethodData<void()>(7, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Method 'fileEntryReferenced'
        QtMocHelpers::MethodData<int(const QString &) const>(9, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 10 },
        }}),
        // Method 'fileEntryIsDirectory'
        QtMocHelpers::MethodData<bool(const QString &) const>(11, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 10 },
        }}),
        // Method 'markArchiveFileForDeletion'
        QtMocHelpers::MethodData<void(const QString &, bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 }, { QMetaType::Bool, 14 },
        }}),
        // Method 'markArchiveFileForDeletion'
        QtMocHelpers::MethodData<void(const QString &)>(12, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Method 'saveBook'
        QtMocHelpers::MethodData<bool()>(15, 2, QMC::AccessPublic, QMetaType::Bool),
        // Method 'removePage'
        QtMocHelpers::MethodData<void(int)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 17 },
        }}),
        // Method 'addPageFromFile'
        QtMocHelpers::MethodData<void(QString, int)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 19 }, { QMetaType::Int, 20 },
        }}),
        // Method 'addPageFromFile'
        QtMocHelpers::MethodData<void(QString)>(18, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 19 },
        }}),
        // Method 'swapPages'
        QtMocHelpers::MethodData<void(int, int)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 22 }, { QMetaType::Int, 23 },
        }}),
        // Method 'createBook'
        QtMocHelpers::MethodData<QString(QString, QString, QString)>(24, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 25 }, { QMetaType::QString, 26 }, { QMetaType::QString, 27 },
        }}),
        // Method 'previewForId'
        QtMocHelpers::MethodData<QString(const QString &) const>(28, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 29 },
        }}),
        // Method 'fontFamilyName'
        QtMocHelpers::MethodData<QString(const QString &)>(30, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 31 },
        }}),
        // Method 'firstAvailableFont'
        QtMocHelpers::MethodData<QString(const QStringList &)>(32, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QStringList, 33 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'qmlEngine'
        QtMocHelpers::PropertyData<QObject*>(34, QMetaType::QObjectStar, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'readWrite'
        QtMocHelpers::PropertyData<bool>(35, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'hasUnsavedChanges'
        QtMocHelpers::PropertyData<bool>(36, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'fileEntries'
        QtMocHelpers::PropertyData<QStringList>(37, QMetaType::QStringList, QMC::DefaultPropertyFlags, 3),
        // property 'fileEntriesToDelete'
        QtMocHelpers::PropertyData<QStringList>(38, QMetaType::QStringList, QMC::DefaultPropertyFlags, 4),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ArchiveBookModel, qt_meta_tag_ZN16ArchiveBookModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ArchiveBookModel::staticMetaObject = { {
    QMetaObject::SuperData::link<BookModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16ArchiveBookModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16ArchiveBookModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16ArchiveBookModelE_t>.metaTypes,
    nullptr
} };

void ArchiveBookModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ArchiveBookModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->qmlEngineChanged(); break;
        case 1: _t->readWriteChanged(); break;
        case 2: _t->hasUnsavedChangesChanged(); break;
        case 3: _t->fileEntriesChanged(); break;
        case 4: _t->fileEntriesToDeleteChanged(); break;
        case 5: _t->setDirty((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->setDirty(); break;
        case 7: { int _r = _t->fileEntryReferenced((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 8: { bool _r = _t->fileEntryIsDirectory((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 9: _t->markArchiveFileForDeletion((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 10: _t->markArchiveFileForDeletion((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: { bool _r = _t->saveBook();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 12: _t->removePage((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 13: _t->addPageFromFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 14: _t->addPageFromFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 15: _t->swapPages((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 16: { QString _r = _t->createBook((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 17: { QString _r = _t->previewForId((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 18: { QString _r = _t->fontFamilyName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 19: { QString _r = _t->firstAvailableFont((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ArchiveBookModel::*)()>(_a, &ArchiveBookModel::qmlEngineChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ArchiveBookModel::*)()>(_a, &ArchiveBookModel::readWriteChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ArchiveBookModel::*)()>(_a, &ArchiveBookModel::hasUnsavedChangesChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ArchiveBookModel::*)()>(_a, &ArchiveBookModel::fileEntriesChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ArchiveBookModel::*)()>(_a, &ArchiveBookModel::fileEntriesToDeleteChanged, 4))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QObject**>(_v) = _t->qmlEngine(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->readWrite(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->hasUnsavedChanges(); break;
        case 3: *reinterpret_cast<QStringList*>(_v) = _t->fileEntries(); break;
        case 4: *reinterpret_cast<QStringList*>(_v) = _t->fileEntriesToDelete(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setQmlEngine(*reinterpret_cast<QObject**>(_v)); break;
        case 1: _t->setReadWrite(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *ArchiveBookModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ArchiveBookModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16ArchiveBookModelE_t>.strings))
        return static_cast<void*>(this);
    return BookModel::qt_metacast(_clname);
}

int ArchiveBookModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = BookModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 20;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void ArchiveBookModel::qmlEngineChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ArchiveBookModel::readWriteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ArchiveBookModel::hasUnsavedChangesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ArchiveBookModel::fileEntriesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void ArchiveBookModel::fileEntriesToDeleteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
