/****************************************************************************
** Meta object code from reading C++ file 'AcbfStyle.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../../mauikit-documents-4.0.2/src/code/cbz/code/acbf/AcbfStyle.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'AcbfStyle.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN23AdvancedComicBookFormat5StyleE_t {};
} // unnamed namespace

template <> constexpr inline auto AdvancedComicBookFormat::Style::qt_create_metaobjectdata<qt_meta_tag_ZN23AdvancedComicBookFormat5StyleE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AdvancedComicBookFormat::Style",
        "elementChanged",
        "",
        "invertedChanged",
        "typeChanged",
        "colorChanged",
        "fontFamilyChanged",
        "fontStyleChanged",
        "fontWeightChanged",
        "fontStretchChanged",
        "styleDataChanged",
        "element",
        "inverted",
        "type",
        "color",
        "fontFamily",
        "fontStyle",
        "fontWeight",
        "fontStretch",
        "string"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'elementChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'invertedChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'typeChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'colorChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fontFamilyChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fontStyleChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fontWeightChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fontStretchChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'styleDataChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'element'
        QtMocHelpers::PropertyData<QString>(11, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'inverted'
        QtMocHelpers::PropertyData<bool>(12, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'type'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'color'
        QtMocHelpers::PropertyData<QString>(14, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'fontFamily'
        QtMocHelpers::PropertyData<QStringList>(15, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'fontStyle'
        QtMocHelpers::PropertyData<QString>(16, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'fontWeight'
        QtMocHelpers::PropertyData<QString>(17, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'fontStretch'
        QtMocHelpers::PropertyData<QString>(18, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'string'
        QtMocHelpers::PropertyData<QString>(19, QMetaType::QString, QMC::DefaultPropertyFlags, 8),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Style, qt_meta_tag_ZN23AdvancedComicBookFormat5StyleE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AdvancedComicBookFormat::Style::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23AdvancedComicBookFormat5StyleE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23AdvancedComicBookFormat5StyleE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23AdvancedComicBookFormat5StyleE_t>.metaTypes,
    nullptr
} };

void AdvancedComicBookFormat::Style::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Style *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->elementChanged(); break;
        case 1: _t->invertedChanged(); break;
        case 2: _t->typeChanged(); break;
        case 3: _t->colorChanged(); break;
        case 4: _t->fontFamilyChanged(); break;
        case 5: _t->fontStyleChanged(); break;
        case 6: _t->fontWeightChanged(); break;
        case 7: _t->fontStretchChanged(); break;
        case 8: _t->styleDataChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Style::*)()>(_a, &Style::elementChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Style::*)()>(_a, &Style::invertedChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Style::*)()>(_a, &Style::typeChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Style::*)()>(_a, &Style::colorChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Style::*)()>(_a, &Style::fontFamilyChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Style::*)()>(_a, &Style::fontStyleChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Style::*)()>(_a, &Style::fontWeightChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Style::*)()>(_a, &Style::fontStretchChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Style::*)()>(_a, &Style::styleDataChanged, 8))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->element(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->inverted(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->type(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->color(); break;
        case 4: *reinterpret_cast<QStringList*>(_v) = _t->fontFamily(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->fontStyle(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->fontWeight(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->fontStretch(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->toString(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setElement(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setInverted(*reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setType(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setColor(*reinterpret_cast<QString*>(_v)); break;
        case 4: _t->setFontFamily(*reinterpret_cast<QStringList*>(_v)); break;
        case 5: _t->setFontStyle(*reinterpret_cast<QString*>(_v)); break;
        case 6: _t->setFontWeight(*reinterpret_cast<QString*>(_v)); break;
        case 7: _t->setFontStretch(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *AdvancedComicBookFormat::Style::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AdvancedComicBookFormat::Style::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23AdvancedComicBookFormat5StyleE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int AdvancedComicBookFormat::Style::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void AdvancedComicBookFormat::Style::elementChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void AdvancedComicBookFormat::Style::invertedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void AdvancedComicBookFormat::Style::typeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void AdvancedComicBookFormat::Style::colorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void AdvancedComicBookFormat::Style::fontFamilyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void AdvancedComicBookFormat::Style::fontStyleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void AdvancedComicBookFormat::Style::fontWeightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void AdvancedComicBookFormat::Style::fontStretchChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void AdvancedComicBookFormat::Style::styleDataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
