/****************************************************************************
** Meta object code from reading C++ file 'AcbfBookinfo.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../../mauikit-documents-4.0.2/src/code/cbz/code/acbf/AcbfBookinfo.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'AcbfBookinfo.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN23AdvancedComicBookFormat8BookInfoE_t {};
} // unnamed namespace

template <> constexpr inline auto AdvancedComicBookFormat::BookInfo::qt_create_metaobjectdata<qt_meta_tag_ZN23AdvancedComicBookFormat8BookInfoE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AdvancedComicBookFormat::BookInfo",
        "authorsChanged",
        "",
        "titleChanged",
        "genresChanged",
        "charactersChanged",
        "languagesChanged",
        "sequenceCountChanged",
        "databaseRefCountChanged",
        "contentRatingCountChanged",
        "rightToLeftChanged",
        "getAuthor",
        "Author*",
        "index",
        "addAuthor",
        "activity",
        "language",
        "firstName",
        "middleName",
        "lastName",
        "nickName",
        "homePages",
        "emails",
        "setAuthor",
        "removeAuthor",
        "titleForAllLanguages",
        "titleLanguages",
        "title",
        "setTitle",
        "genre",
        "QHash<QString,int>",
        "genres",
        "genrePercentage",
        "setGenre",
        "matchPercentage",
        "removeGenre",
        "availableGenres",
        "characters",
        "addCharacter",
        "name",
        "removeCharacter",
        "setCharacters",
        "annotationsForAllLanguage",
        "QList<QStringList>",
        "annotationLanguages",
        "annotation",
        "setAnnotation",
        "keywords",
        "setKeywords",
        "coverpage",
        "Page*",
        "addLanguage",
        "show",
        "removeLanguage",
        "addSequence",
        "number",
        "volume",
        "removeSequence",
        "sequence",
        "Sequence*",
        "sequenceCount",
        "addDatabaseRef",
        "reference",
        "dbname",
        "type",
        "removeDatabaseRef",
        "databaseRef",
        "DatabaseRef*",
        "databaseRefCount",
        "addContentRating",
        "rating",
        "removeContentRating",
        "contentRating",
        "ContentRating*",
        "contentRatingCount",
        "authorNames",
        "languages",
        "QObjectList",
        "languageEntryList",
        "rightToLeft"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'authorsChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'titleChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'genresChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'charactersChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'languagesChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sequenceCountChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'databaseRefCountChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'contentRatingCountChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'rightToLeftChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'getAuthor'
        QtMocHelpers::MethodData<Author *(int) const>(11, 2, QMC::AccessPublic, 0x80000000 | 12, {{
            { QMetaType::Int, 13 },
        }}),
        // Method 'addAuthor'
        QtMocHelpers::MethodData<void(QString, QString, QString, QString, QString, QString, QStringList, QStringList)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 15 }, { QMetaType::QString, 16 }, { QMetaType::QString, 17 }, { QMetaType::QString, 18 },
            { QMetaType::QString, 19 }, { QMetaType::QString, 20 }, { QMetaType::QStringList, 21 }, { QMetaType::QStringList, 22 },
        }}),
        // Method 'setAuthor'
        QtMocHelpers::MethodData<void(int, QString, QString, QString, QString, QString, QString, QStringList, QStringList)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 13 }, { QMetaType::QString, 15 }, { QMetaType::QString, 16 }, { QMetaType::QString, 17 },
            { QMetaType::QString, 18 }, { QMetaType::QString, 19 }, { QMetaType::QString, 20 }, { QMetaType::QStringList, 21 },
            { QMetaType::QStringList, 22 },
        }}),
        // Method 'removeAuthor'
        QtMocHelpers::MethodData<void(int)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 13 },
        }}),
        // Method 'titleForAllLanguages'
        QtMocHelpers::MethodData<QStringList()>(25, 2, QMC::AccessPublic, QMetaType::QStringList),
        // Method 'titleLanguages'
        QtMocHelpers::MethodData<QStringList()>(26, 2, QMC::AccessPublic, QMetaType::QStringList),
        // Method 'title'
        QtMocHelpers::MethodData<QString(QString)>(27, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 16 },
        }}),
        // Method 'title'
        QtMocHelpers::MethodData<QString()>(27, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString),
        // Method 'setTitle'
        QtMocHelpers::MethodData<void(QString, QString)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 27 }, { QMetaType::QString, 16 },
        }}),
        // Method 'setTitle'
        QtMocHelpers::MethodData<void(QString)>(28, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 27 },
        }}),
        // Method 'genre'
        QtMocHelpers::MethodData<QHash<QString,int>()>(29, 2, QMC::AccessPublic, 0x80000000 | 30),
        // Method 'genres'
        QtMocHelpers::MethodData<QStringList() const>(31, 2, QMC::AccessPublic, QMetaType::QStringList),
        // Method 'genrePercentage'
        QtMocHelpers::MethodData<int(QString) const>(32, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 29 },
        }}),
        // Method 'setGenre'
        QtMocHelpers::MethodData<void(QString, int)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 29 }, { QMetaType::Int, 34 },
        }}),
        // Method 'setGenre'
        QtMocHelpers::MethodData<void(QString)>(33, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 29 },
        }}),
        // Method 'removeGenre'
        QtMocHelpers::MethodData<void(QString)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 29 },
        }}),
        // Method 'availableGenres'
        QtMocHelpers::MethodData<QStringList()>(36, 2, QMC::AccessPublic, QMetaType::QStringList),
        // Method 'characters'
        QtMocHelpers::MethodData<QStringList()>(37, 2, QMC::AccessPublic, QMetaType::QStringList),
        // Method 'addCharacter'
        QtMocHelpers::MethodData<void(QString)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 39 },
        }}),
        // Method 'removeCharacter'
        QtMocHelpers::MethodData<void(QString)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 39 },
        }}),
        // Method 'setCharacters'
        QtMocHelpers::MethodData<void(QStringList)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 37 },
        }}),
        // Method 'annotationsForAllLanguage'
        QtMocHelpers::MethodData<QList<QStringList>()>(42, 2, QMC::AccessPublic, 0x80000000 | 43),
        // Method 'annotationLanguages'
        QtMocHelpers::MethodData<QStringList()>(44, 2, QMC::AccessPublic, QMetaType::QStringList),
        // Method 'annotation'
        QtMocHelpers::MethodData<QStringList(QString)>(45, 2, QMC::AccessPublic, QMetaType::QStringList, {{
            { QMetaType::QString, 16 },
        }}),
        // Method 'annotation'
        QtMocHelpers::MethodData<QStringList()>(45, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QStringList),
        // Method 'setAnnotation'
        QtMocHelpers::MethodData<void(QStringList, QString)>(46, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 45 }, { QMetaType::QString, 16 },
        }}),
        // Method 'setAnnotation'
        QtMocHelpers::MethodData<void(QStringList)>(46, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QStringList, 45 },
        }}),
        // Method 'keywords'
        QtMocHelpers::MethodData<QStringList(QString)>(47, 2, QMC::AccessPublic, QMetaType::QStringList, {{
            { QMetaType::QString, 16 },
        }}),
        // Method 'keywords'
        QtMocHelpers::MethodData<QStringList()>(47, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QStringList),
        // Method 'setKeywords'
        QtMocHelpers::MethodData<void(QStringList, QString)>(48, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 47 }, { QMetaType::QString, 16 },
        }}),
        // Method 'setKeywords'
        QtMocHelpers::MethodData<void(QStringList)>(48, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QStringList, 47 },
        }}),
        // Method 'coverpage'
        QtMocHelpers::MethodData<Page *()>(49, 2, QMC::AccessPublic, 0x80000000 | 50),
        // Method 'addLanguage'
        QtMocHelpers::MethodData<void(QString, bool)>(51, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 16 }, { QMetaType::Bool, 52 },
        }}),
        // Method 'addLanguage'
        QtMocHelpers::MethodData<void(QString)>(51, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 16 },
        }}),
        // Method 'addLanguage'
        QtMocHelpers::MethodData<void()>(51, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Method 'removeLanguage'
        QtMocHelpers::MethodData<void(int)>(53, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 13 },
        }}),
        // Method 'addSequence'
        QtMocHelpers::MethodData<void(int, QString, int)>(54, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 55 }, { QMetaType::QString, 27 }, { QMetaType::Int, 56 },
        }}),
        // Method 'addSequence'
        QtMocHelpers::MethodData<void(int, QString)>(54, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 55 }, { QMetaType::QString, 27 },
        }}),
        // Method 'addSequence'
        QtMocHelpers::MethodData<void(int)>(54, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 55 },
        }}),
        // Method 'removeSequence'
        QtMocHelpers::MethodData<void(int)>(57, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 13 },
        }}),
        // Method 'sequence'
        QtMocHelpers::MethodData<Sequence *(int) const>(58, 2, QMC::AccessPublic, 0x80000000 | 59, {{
            { QMetaType::Int, 13 },
        }}),
        // Method 'sequenceCount'
        QtMocHelpers::MethodData<int() const>(60, 2, QMC::AccessPublic, QMetaType::Int),
        // Method 'addDatabaseRef'
        QtMocHelpers::MethodData<void(QString, QString, QString)>(61, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 62 }, { QMetaType::QString, 63 }, { QMetaType::QString, 64 },
        }}),
        // Method 'addDatabaseRef'
        QtMocHelpers::MethodData<void(QString, QString)>(61, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 62 }, { QMetaType::QString, 63 },
        }}),
        // Method 'removeDatabaseRef'
        QtMocHelpers::MethodData<void(int)>(65, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 13 },
        }}),
        // Method 'databaseRef'
        QtMocHelpers::MethodData<DatabaseRef *(int)>(66, 2, QMC::AccessPublic, 0x80000000 | 67, {{
            { QMetaType::Int, 13 },
        }}),
        // Method 'databaseRefCount'
        QtMocHelpers::MethodData<int()>(68, 2, QMC::AccessPublic, QMetaType::Int),
        // Method 'addContentRating'
        QtMocHelpers::MethodData<void(QString, QString)>(69, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 70 }, { QMetaType::QString, 64 },
        }}),
        // Method 'addContentRating'
        QtMocHelpers::MethodData<void(QString)>(69, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 70 },
        }}),
        // Method 'removeContentRating'
        QtMocHelpers::MethodData<void(int)>(71, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 13 },
        }}),
        // Method 'contentRating'
        QtMocHelpers::MethodData<ContentRating *(int)>(72, 2, QMC::AccessPublic, 0x80000000 | 73, {{
            { QMetaType::Int, 13 },
        }}),
        // Method 'contentRatingCount'
        QtMocHelpers::MethodData<int()>(74, 2, QMC::AccessPublic, QMetaType::Int),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'authorNames'
        QtMocHelpers::PropertyData<QStringList>(75, QMetaType::QStringList, QMC::DefaultPropertyFlags, 0),
        // property 'titleLanguages'
        QtMocHelpers::PropertyData<QStringList>(26, QMetaType::QStringList, QMC::DefaultPropertyFlags, 1),
        // property 'genres'
        QtMocHelpers::PropertyData<QStringList>(31, QMetaType::QStringList, QMC::DefaultPropertyFlags, 2),
        // property 'characters'
        QtMocHelpers::PropertyData<QStringList>(37, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'languages'
        QtMocHelpers::PropertyData<QObjectList>(76, 0x80000000 | 77, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 4),
        // property 'languageEntryList'
        QtMocHelpers::PropertyData<QStringList>(78, QMetaType::QStringList, QMC::DefaultPropertyFlags, 4),
        // property 'sequenceCount'
        QtMocHelpers::PropertyData<int>(60, QMetaType::Int, QMC::DefaultPropertyFlags, 5),
        // property 'databaseRefCount'
        QtMocHelpers::PropertyData<int>(68, QMetaType::Int, QMC::DefaultPropertyFlags, 6),
        // property 'contentRatingCount'
        QtMocHelpers::PropertyData<int>(74, QMetaType::Int, QMC::DefaultPropertyFlags, 7),
        // property 'rightToLeft'
        QtMocHelpers::PropertyData<bool>(79, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<BookInfo, qt_meta_tag_ZN23AdvancedComicBookFormat8BookInfoE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AdvancedComicBookFormat::BookInfo::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23AdvancedComicBookFormat8BookInfoE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23AdvancedComicBookFormat8BookInfoE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23AdvancedComicBookFormat8BookInfoE_t>.metaTypes,
    nullptr
} };

void AdvancedComicBookFormat::BookInfo::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BookInfo *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->authorsChanged(); break;
        case 1: _t->titleChanged(); break;
        case 2: _t->genresChanged(); break;
        case 3: _t->charactersChanged(); break;
        case 4: _t->languagesChanged(); break;
        case 5: _t->sequenceCountChanged(); break;
        case 6: _t->databaseRefCountChanged(); break;
        case 7: _t->contentRatingCountChanged(); break;
        case 8: _t->rightToLeftChanged(); break;
        case 9: { Author* _r = _t->getAuthor((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Author**>(_a[0]) = std::move(_r); }  break;
        case 10: _t->addAuthor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[8]))); break;
        case 11: _t->setAuthor((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[8])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[9]))); break;
        case 12: _t->removeAuthor((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 13: { QStringList _r = _t->titleForAllLanguages();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 14: { QStringList _r = _t->titleLanguages();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 15: { QString _r = _t->title((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 16: { QString _r = _t->title();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 17: _t->setTitle((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 18: _t->setTitle((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 19: { QHash<QString,int> _r = _t->genre();
            if (_a[0]) *reinterpret_cast<QHash<QString,int>*>(_a[0]) = std::move(_r); }  break;
        case 20: { QStringList _r = _t->genres();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 21: { int _r = _t->genrePercentage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 22: _t->setGenre((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 23: _t->setGenre((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 24: _t->removeGenre((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 25: { QStringList _r = _t->availableGenres();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 26: { QStringList _r = _t->characters();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 27: _t->addCharacter((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 28: _t->removeCharacter((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 29: _t->setCharacters((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 30: { QList<QStringList> _r = _t->annotationsForAllLanguage();
            if (_a[0]) *reinterpret_cast<QList<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 31: { QStringList _r = _t->annotationLanguages();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 32: { QStringList _r = _t->annotation((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 33: { QStringList _r = _t->annotation();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 34: _t->setAnnotation((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 35: _t->setAnnotation((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 36: { QStringList _r = _t->keywords((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 37: { QStringList _r = _t->keywords();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 38: _t->setKeywords((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 39: _t->setKeywords((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 40: { Page* _r = _t->coverpage();
            if (_a[0]) *reinterpret_cast<Page**>(_a[0]) = std::move(_r); }  break;
        case 41: _t->addLanguage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 42: _t->addLanguage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 43: _t->addLanguage(); break;
        case 44: _t->removeLanguage((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 45: _t->addSequence((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 46: _t->addSequence((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 47: _t->addSequence((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 48: _t->removeSequence((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 49: { Sequence* _r = _t->sequence((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Sequence**>(_a[0]) = std::move(_r); }  break;
        case 50: { int _r = _t->sequenceCount();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 51: _t->addDatabaseRef((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 52: _t->addDatabaseRef((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 53: _t->removeDatabaseRef((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 54: { DatabaseRef* _r = _t->databaseRef((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<DatabaseRef**>(_a[0]) = std::move(_r); }  break;
        case 55: { int _r = _t->databaseRefCount();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 56: _t->addContentRating((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 57: _t->addContentRating((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 58: _t->removeContentRating((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 59: { ContentRating* _r = _t->contentRating((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<ContentRating**>(_a[0]) = std::move(_r); }  break;
        case 60: { int _r = _t->contentRatingCount();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (BookInfo::*)()>(_a, &BookInfo::authorsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (BookInfo::*)()>(_a, &BookInfo::titleChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (BookInfo::*)()>(_a, &BookInfo::genresChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (BookInfo::*)()>(_a, &BookInfo::charactersChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (BookInfo::*)()>(_a, &BookInfo::languagesChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (BookInfo::*)()>(_a, &BookInfo::sequenceCountChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (BookInfo::*)()>(_a, &BookInfo::databaseRefCountChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (BookInfo::*)()>(_a, &BookInfo::contentRatingCountChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (BookInfo::*)()>(_a, &BookInfo::rightToLeftChanged, 8))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QStringList*>(_v) = _t->authorNames(); break;
        case 1: *reinterpret_cast<QStringList*>(_v) = _t->titleLanguages(); break;
        case 2: *reinterpret_cast<QStringList*>(_v) = _t->genres(); break;
        case 3: *reinterpret_cast<QStringList*>(_v) = _t->characters(); break;
        case 4: *reinterpret_cast<QObjectList*>(_v) = _t->languages(); break;
        case 5: *reinterpret_cast<QStringList*>(_v) = _t->languageEntryList(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->sequenceCount(); break;
        case 7: *reinterpret_cast<int*>(_v) = _t->databaseRefCount(); break;
        case 8: *reinterpret_cast<int*>(_v) = _t->contentRatingCount(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->rightToLeft(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 3: _t->setCharacters(*reinterpret_cast<QStringList*>(_v)); break;
        case 9: _t->setRightToLeft(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *AdvancedComicBookFormat::BookInfo::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AdvancedComicBookFormat::BookInfo::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23AdvancedComicBookFormat8BookInfoE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int AdvancedComicBookFormat::BookInfo::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 61)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 61;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 61)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 61;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void AdvancedComicBookFormat::BookInfo::authorsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void AdvancedComicBookFormat::BookInfo::titleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void AdvancedComicBookFormat::BookInfo::genresChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void AdvancedComicBookFormat::BookInfo::charactersChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void AdvancedComicBookFormat::BookInfo::languagesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void AdvancedComicBookFormat::BookInfo::sequenceCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void AdvancedComicBookFormat::BookInfo::databaseRefCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void AdvancedComicBookFormat::BookInfo::contentRatingCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void AdvancedComicBookFormat::BookInfo::rightToLeftChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
