/****************************************************************************
** Meta object code from reading C++ file 'BookModel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../mauikit-documents-4.0.2/src/code/cbz/code/BookModel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'BookModel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9BookModelE_t {};
} // unnamed namespace

template <> constexpr inline auto BookModel::qt_create_metaobjectdata<qt_meta_tag_ZN9BookModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BookModel",
        "filenameChanged",
        "",
        "authorChanged",
        "publisherChanged",
        "titleChanged",
        "pageCountChanged",
        "currentPageChanged",
        "acbfDataChanged",
        "processingChanged",
        "loadingCompleted",
        "success",
        "processingDescriptionChanged",
        "swapPages",
        "swapThisIndex",
        "withThisIndex",
        "filename",
        "author",
        "publisher",
        "title",
        "pageCount",
        "currentPage",
        "acbfData",
        "processing",
        "processingDescription"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'filenameChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'authorChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'publisherChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'titleChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pageCountChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentPageChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'acbfDataChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'processingChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'loadingCompleted'
        QtMocHelpers::SignalData<void(bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Signal 'processingDescriptionChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'swapPages'
        QtMocHelpers::MethodData<void(int, int)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 14 }, { QMetaType::Int, 15 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'filename'
        QtMocHelpers::PropertyData<QString>(16, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'author'
        QtMocHelpers::PropertyData<QString>(17, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'publisher'
        QtMocHelpers::PropertyData<QString>(18, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'title'
        QtMocHelpers::PropertyData<QString>(19, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'pageCount'
        QtMocHelpers::PropertyData<int>(20, QMetaType::Int, QMC::DefaultPropertyFlags, 4),
        // property 'currentPage'
        QtMocHelpers::PropertyData<int>(21, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'acbfData'
        QtMocHelpers::PropertyData<QObject*>(22, QMetaType::QObjectStar, QMC::DefaultPropertyFlags, 6),
        // property 'processing'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'processingDescription'
        QtMocHelpers::PropertyData<QString>(24, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<BookModel, qt_meta_tag_ZN9BookModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject BookModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9BookModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9BookModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9BookModelE_t>.metaTypes,
    nullptr
} };

void BookModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BookModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->filenameChanged(); break;
        case 1: _t->authorChanged(); break;
        case 2: _t->publisherChanged(); break;
        case 3: _t->titleChanged(); break;
        case 4: _t->pageCountChanged(); break;
        case 5: _t->currentPageChanged(); break;
        case 6: _t->acbfDataChanged(); break;
        case 7: _t->processingChanged(); break;
        case 8: _t->loadingCompleted((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->processingDescriptionChanged(); break;
        case 10: _t->swapPages((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (BookModel::*)()>(_a, &BookModel::filenameChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (BookModel::*)()>(_a, &BookModel::authorChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (BookModel::*)()>(_a, &BookModel::publisherChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (BookModel::*)()>(_a, &BookModel::titleChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (BookModel::*)()>(_a, &BookModel::pageCountChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (BookModel::*)()>(_a, &BookModel::currentPageChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (BookModel::*)()>(_a, &BookModel::acbfDataChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (BookModel::*)()>(_a, &BookModel::processingChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (BookModel::*)(bool )>(_a, &BookModel::loadingCompleted, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (BookModel::*)()>(_a, &BookModel::processingDescriptionChanged, 9))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->filename(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->author(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->publisher(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->title(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->pageCount(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->currentPage(); break;
        case 6: *reinterpret_cast<QObject**>(_v) = _t->acbfData(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->processing(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->processingDescription(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setFilename(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setAuthor(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setPublisher(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setTitle(*reinterpret_cast<QString*>(_v)); break;
        case 5: _t->setCurrentPage(*reinterpret_cast<int*>(_v)); break;
        case 7: _t->setProcessing(*reinterpret_cast<bool*>(_v)); break;
        case 8: _t->setProcessingDescription(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *BookModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BookModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9BookModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int BookModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void BookModel::filenameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void BookModel::authorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void BookModel::publisherChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void BookModel::titleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void BookModel::pageCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void BookModel::currentPageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void BookModel::acbfDataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void BookModel::processingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void BookModel::loadingCompleted(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void BookModel::processingDescriptionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}
QT_WARNING_POP
