/****************************************************************************
** Meta object code from reading C++ file 'AcbfAuthor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../../mauikit-documents-4.0.2/src/code/cbz/code/acbf/AcbfAuthor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'AcbfAuthor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN23AdvancedComicBookFormat6AuthorE_t {};
} // unnamed namespace

template <> constexpr inline auto AdvancedComicBookFormat::Author::qt_create_metaobjectdata<qt_meta_tag_ZN23AdvancedComicBookFormat6AuthorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AdvancedComicBookFormat::Author",
        "homePagesChanged",
        "",
        "emailsChanged",
        "displayName",
        "activity",
        "setActivity",
        "availableActivities",
        "language",
        "setLanguage",
        "firstName",
        "setFirstName",
        "name",
        "middleName",
        "setMiddleName",
        "lastName",
        "setLastName",
        "nickName",
        "setNickName",
        "homePages",
        "addHomePage",
        "homepage",
        "removeHomePage",
        "index",
        "setHomePages",
        "homepages",
        "emails",
        "addEmail",
        "email",
        "removeEmail",
        "setEmails"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'homePagesChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'emailsChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'displayName'
        QtMocHelpers::MethodData<QString() const>(4, 2, QMC::AccessPublic, QMetaType::QString),
        // Method 'activity'
        QtMocHelpers::MethodData<QString() const>(5, 2, QMC::AccessPublic, QMetaType::QString),
        // Method 'setActivity'
        QtMocHelpers::MethodData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Method 'availableActivities'
        QtMocHelpers::MethodData<QStringList()>(7, 2, QMC::AccessPublic, QMetaType::QStringList),
        // Method 'language'
        QtMocHelpers::MethodData<QString() const>(8, 2, QMC::AccessPublic, QMetaType::QString),
        // Method 'setLanguage'
        QtMocHelpers::MethodData<void(const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Method 'setLanguage'
        QtMocHelpers::MethodData<void()>(9, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Method 'firstName'
        QtMocHelpers::MethodData<QString() const>(10, 2, QMC::AccessPublic, QMetaType::QString),
        // Method 'setFirstName'
        QtMocHelpers::MethodData<void(const QString &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Method 'middleName'
        QtMocHelpers::MethodData<QString() const>(13, 2, QMC::AccessPublic, QMetaType::QString),
        // Method 'setMiddleName'
        QtMocHelpers::MethodData<void(const QString &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Method 'lastName'
        QtMocHelpers::MethodData<QString() const>(15, 2, QMC::AccessPublic, QMetaType::QString),
        // Method 'setLastName'
        QtMocHelpers::MethodData<void(const QString &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Method 'nickName'
        QtMocHelpers::MethodData<QString() const>(17, 2, QMC::AccessPublic, QMetaType::QString),
        // Method 'setNickName'
        QtMocHelpers::MethodData<void(const QString &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Method 'homePages'
        QtMocHelpers::MethodData<QStringList() const>(19, 2, QMC::AccessPublic, QMetaType::QStringList),
        // Method 'addHomePage'
        QtMocHelpers::MethodData<void(const QString &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 21 },
        }}),
        // Method 'removeHomePage'
        QtMocHelpers::MethodData<void(const int &)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 23 },
        }}),
        // Method 'setHomePages'
        QtMocHelpers::MethodData<void(const QStringList &)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 25 },
        }}),
        // Method 'emails'
        QtMocHelpers::MethodData<QStringList() const>(26, 2, QMC::AccessPublic, QMetaType::QStringList),
        // Method 'addEmail'
        QtMocHelpers::MethodData<void(const QString &)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 28 },
        }}),
        // Method 'removeEmail'
        QtMocHelpers::MethodData<void(const int &)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 23 },
        }}),
        // Method 'setEmails'
        QtMocHelpers::MethodData<void(const QStringList &)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 26 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'homePages'
        QtMocHelpers::PropertyData<QStringList>(19, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'emails'
        QtMocHelpers::PropertyData<QStringList>(26, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Author, qt_meta_tag_ZN23AdvancedComicBookFormat6AuthorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AdvancedComicBookFormat::Author::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23AdvancedComicBookFormat6AuthorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23AdvancedComicBookFormat6AuthorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23AdvancedComicBookFormat6AuthorE_t>.metaTypes,
    nullptr
} };

void AdvancedComicBookFormat::Author::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Author *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->homePagesChanged(); break;
        case 1: _t->emailsChanged(); break;
        case 2: { QString _r = _t->displayName();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 3: { QString _r = _t->activity();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 4: _t->setActivity((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: { QStringList _r = _t->availableActivities();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 6: { QString _r = _t->language();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 7: _t->setLanguage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->setLanguage(); break;
        case 9: { QString _r = _t->firstName();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->setFirstName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: { QString _r = _t->middleName();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 12: _t->setMiddleName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: { QString _r = _t->lastName();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 14: _t->setLastName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 15: { QString _r = _t->nickName();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 16: _t->setNickName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 17: { QStringList _r = _t->homePages();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 18: _t->addHomePage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 19: _t->removeHomePage((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 20: _t->setHomePages((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 21: { QStringList _r = _t->emails();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 22: _t->addEmail((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 23: _t->removeEmail((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 24: _t->setEmails((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Author::*)()>(_a, &Author::homePagesChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Author::*)()>(_a, &Author::emailsChanged, 1))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QStringList*>(_v) = _t->homePages(); break;
        case 1: *reinterpret_cast<QStringList*>(_v) = _t->emails(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setHomePages(*reinterpret_cast<QStringList*>(_v)); break;
        case 1: _t->setEmails(*reinterpret_cast<QStringList*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *AdvancedComicBookFormat::Author::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AdvancedComicBookFormat::Author::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23AdvancedComicBookFormat6AuthorE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int AdvancedComicBookFormat::Author::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 25)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 25)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 25;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void AdvancedComicBookFormat::Author::homePagesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void AdvancedComicBookFormat::Author::emailsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
