/****************************************************************************
** Meta object code from reading C++ file 'pdfdocument.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../mauikit-documents-4.0.2/src/code/poppler/code/pdfdocument.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'pdfdocument.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11PdfDocumentE_t {};
} // unnamed namespace

template <> constexpr inline auto PdfDocument::qt_create_metaobjectdata<qt_meta_tag_ZN11PdfDocumentE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PdfDocument",
        "pathChanged",
        "",
        "error",
        "errorMessage",
        "pagesLoaded",
        "providersNumberChanged",
        "tocModelChanged",
        "pagesCountChanged",
        "documentLocked",
        "titleChanged",
        "isLockedChanged",
        "isValidChanged",
        "unlock",
        "ownerPassword",
        "password",
        "search",
        "QVariantList",
        "page",
        "text",
        "Qt::CaseSensitivity",
        "caseSensitivity",
        "getText",
        "QRectF",
        "rect",
        "QSize",
        "pageSize",
        "getDocumentDate",
        "data",
        "getDocumentInfo",
        "title",
        "path",
        "QUrl",
        "pages",
        "providersNumber",
        "tocModel",
        "isLocked",
        "isValid",
        "id"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'pathChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'error'
        QtMocHelpers::SignalData<void(const QString &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'pagesLoaded'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'providersNumberChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'tocModelChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pagesCountChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'documentLocked'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'titleChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'isLockedChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'isValidChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'unlock'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 }, { QMetaType::QString, 15 },
        }}),
        // Slot 'search'
        QtMocHelpers::SlotData<QVariantList(int, const QString &, Qt::CaseSensitivity)>(16, 2, QMC::AccessPublic, 0x80000000 | 17, {{
            { QMetaType::Int, 18 }, { QMetaType::QString, 19 }, { 0x80000000 | 20, 21 },
        }}),
        // Slot 'search'
        QtMocHelpers::SlotData<QVariantList(int, const QString &)>(16, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 17, {{
            { QMetaType::Int, 18 }, { QMetaType::QString, 19 },
        }}),
        // Slot 'getText'
        QtMocHelpers::SlotData<QString(const QRectF &, const QSize &, int)>(22, 2, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 23, 24 }, { 0x80000000 | 25, 26 }, { QMetaType::Int, 18 },
        }}),
        // Method 'getDocumentDate'
        QtMocHelpers::MethodData<QDateTime(QString)>(27, 2, QMC::AccessPublic, QMetaType::QDateTime, {{
            { QMetaType::QString, 28 },
        }}),
        // Method 'getDocumentInfo'
        QtMocHelpers::MethodData<QString(QString) const>(29, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 28 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'title'
        QtMocHelpers::PropertyData<QString>(30, QMetaType::QString, QMC::DefaultPropertyFlags, 7),
        // property 'path'
        QtMocHelpers::PropertyData<QUrl>(31, 0x80000000 | 32, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'pages'
        QtMocHelpers::PropertyData<int>(33, QMetaType::Int, QMC::DefaultPropertyFlags, 5),
        // property 'providersNumber'
        QtMocHelpers::PropertyData<int>(34, QMetaType::Int, QMC::DefaultPropertyFlags, 3),
        // property 'tocModel'
        QtMocHelpers::PropertyData<QObject*>(35, QMetaType::QObjectStar, QMC::DefaultPropertyFlags, 4),
        // property 'isLocked'
        QtMocHelpers::PropertyData<bool>(36, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Final, 8),
        // property 'isValid'
        QtMocHelpers::PropertyData<bool>(37, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Final, 9),
        // property 'id'
        QtMocHelpers::PropertyData<QString>(38, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PdfDocument, qt_meta_tag_ZN11PdfDocumentE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PdfDocument::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PdfDocumentE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PdfDocumentE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11PdfDocumentE_t>.metaTypes,
    nullptr
} };

void PdfDocument::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PdfDocument *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->pathChanged(); break;
        case 1: _t->error((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->pagesLoaded(); break;
        case 3: _t->providersNumberChanged(); break;
        case 4: _t->tocModelChanged(); break;
        case 5: _t->pagesCountChanged(); break;
        case 6: _t->documentLocked(); break;
        case 7: _t->titleChanged(); break;
        case 8: _t->isLockedChanged(); break;
        case 9: _t->isValidChanged(); break;
        case 10: _t->unlock((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 11: { QVariantList _r = _t->search((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Qt::CaseSensitivity>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 12: { QVariantList _r = _t->search((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 13: { QString _r = _t->getText((*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QSize>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 14: { QDateTime _r = _t->getDocumentDate((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDateTime*>(_a[0]) = std::move(_r); }  break;
        case 15: { QString _r = _t->getDocumentInfo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PdfDocument::*)()>(_a, &PdfDocument::pathChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PdfDocument::*)(const QString & )>(_a, &PdfDocument::error, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PdfDocument::*)()>(_a, &PdfDocument::pagesLoaded, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PdfDocument::*)()>(_a, &PdfDocument::providersNumberChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (PdfDocument::*)()>(_a, &PdfDocument::tocModelChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (PdfDocument::*)()>(_a, &PdfDocument::pagesCountChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (PdfDocument::*)()>(_a, &PdfDocument::documentLocked, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (PdfDocument::*)()>(_a, &PdfDocument::titleChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (PdfDocument::*)()>(_a, &PdfDocument::isLockedChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (PdfDocument::*)()>(_a, &PdfDocument::isValidChanged, 9))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->title(); break;
        case 1: *reinterpret_cast<QUrl*>(_v) = _t->path(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->pageCount(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->providersNumber(); break;
        case 4: *reinterpret_cast<QObject**>(_v) = _t->tocModel(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->isLocked(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->isValid(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->id(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setPath(*reinterpret_cast<QUrl*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *PdfDocument::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PdfDocument::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PdfDocumentE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int PdfDocument::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 16;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void PdfDocument::pathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void PdfDocument::error(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void PdfDocument::pagesLoaded()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void PdfDocument::providersNumberChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void PdfDocument::tocModelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void PdfDocument::pagesCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void PdfDocument::documentLocked()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void PdfDocument::titleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void PdfDocument::isLockedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void PdfDocument::isValidChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}
QT_WARNING_POP
