/****************************************************************************
** Meta object code from reading C++ file 'AcbfJump.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../../mauikit-documents-4.0.2/src/code/cbz/code/acbf/AcbfJump.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'AcbfJump.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN23AdvancedComicBookFormat4JumpE_t {};
} // unnamed namespace

template <> constexpr inline auto AdvancedComicBookFormat::Jump::qt_create_metaobjectdata<qt_meta_tag_ZN23AdvancedComicBookFormat4JumpE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AdvancedComicBookFormat::Jump",
        "pointCountChanged",
        "",
        "boundsChanged",
        "pageIndexChanged",
        "hrefChanged",
        "point",
        "QPoint",
        "index",
        "pointIndex",
        "addPoint",
        "removePoint",
        "setPointsFromRect",
        "topLeft",
        "bottomRight",
        "pointCount",
        "bounds",
        "QRect",
        "pageIndex",
        "href"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'pointCountChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'boundsChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pageIndexChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hrefChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'point'
        QtMocHelpers::MethodData<QPoint(int) const>(6, 2, QMC::AccessPublic, 0x80000000 | 7, {{
            { QMetaType::Int, 8 },
        }}),
        // Method 'pointIndex'
        QtMocHelpers::MethodData<int(const QPoint &) const>(9, 2, QMC::AccessPublic, QMetaType::Int, {{
            { 0x80000000 | 7, 6 },
        }}),
        // Method 'addPoint'
        QtMocHelpers::MethodData<void(const QPoint &, int)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 6 }, { QMetaType::Int, 8 },
        }}),
        // Method 'addPoint'
        QtMocHelpers::MethodData<void(const QPoint &)>(10, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 7, 6 },
        }}),
        // Method 'removePoint'
        QtMocHelpers::MethodData<void(const QPoint &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 6 },
        }}),
        // Method 'setPointsFromRect'
        QtMocHelpers::MethodData<void(const QPoint &, const QPoint &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 13 }, { 0x80000000 | 7, 14 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'pointCount'
        QtMocHelpers::PropertyData<int>(15, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
        // property 'bounds'
        QtMocHelpers::PropertyData<QRect>(16, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'pageIndex'
        QtMocHelpers::PropertyData<int>(18, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'href'
        QtMocHelpers::PropertyData<QString>(19, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Jump, qt_meta_tag_ZN23AdvancedComicBookFormat4JumpE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AdvancedComicBookFormat::Jump::staticMetaObject = { {
    QMetaObject::SuperData::link<InternalReferenceObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23AdvancedComicBookFormat4JumpE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23AdvancedComicBookFormat4JumpE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23AdvancedComicBookFormat4JumpE_t>.metaTypes,
    nullptr
} };

void AdvancedComicBookFormat::Jump::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Jump *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->pointCountChanged(); break;
        case 1: _t->boundsChanged(); break;
        case 2: _t->pageIndexChanged(); break;
        case 3: _t->hrefChanged(); break;
        case 4: { QPoint _r = _t->point((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QPoint*>(_a[0]) = std::move(_r); }  break;
        case 5: { int _r = _t->pointIndex((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 6: _t->addPoint((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 7: _t->addPoint((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 8: _t->removePoint((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 9: _t->setPointsFromRect((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Jump::*)()>(_a, &Jump::pointCountChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Jump::*)()>(_a, &Jump::boundsChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Jump::*)()>(_a, &Jump::pageIndexChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Jump::*)()>(_a, &Jump::hrefChanged, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->pointCount(); break;
        case 1: *reinterpret_cast<QRect*>(_v) = _t->bounds(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->pageIndex(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->href(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 2: _t->setPageIndex(*reinterpret_cast<int*>(_v)); break;
        case 3: _t->setHref(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *AdvancedComicBookFormat::Jump::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AdvancedComicBookFormat::Jump::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23AdvancedComicBookFormat4JumpE_t>.strings))
        return static_cast<void*>(this);
    return InternalReferenceObject::qt_metacast(_clname);
}

int AdvancedComicBookFormat::Jump::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = InternalReferenceObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void AdvancedComicBookFormat::Jump::pointCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void AdvancedComicBookFormat::Jump::boundsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void AdvancedComicBookFormat::Jump::pageIndexChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void AdvancedComicBookFormat::Jump::hrefChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
