/****************************************************************************
** Meta object code from reading C++ file 'AcbfReferences.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../../mauikit-documents-4.0.2/src/code/cbz/code/acbf/AcbfReferences.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'AcbfReferences.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN23AdvancedComicBookFormat10ReferencesE_t {};
} // unnamed namespace

template <> constexpr inline auto AdvancedComicBookFormat::References::qt_create_metaobjectdata<qt_meta_tag_ZN23AdvancedComicBookFormat10ReferencesE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AdvancedComicBookFormat::References",
        "referencesChanged",
        "",
        "referenceAdded",
        "referece",
        "addReference",
        "AdvancedComicBookFormat::Reference*",
        "id",
        "paragraphs",
        "language",
        "swapReferences",
        "swapThis",
        "withThis",
        "swapReferencesByIndex",
        "references",
        "QObjectList",
        "referenceIds"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'referencesChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'referenceAdded'
        QtMocHelpers::SignalData<void(QObject *)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QObjectStar, 4 },
        }}),
        // Method 'addReference'
        QtMocHelpers::MethodData<AdvancedComicBookFormat::Reference *(const QString &, const QStringList &, const QString &)>(5, 2, QMC::AccessPublic, 0x80000000 | 6, {{
            { QMetaType::QString, 7 }, { QMetaType::QStringList, 8 }, { QMetaType::QString, 9 },
        }}),
        // Method 'addReference'
        QtMocHelpers::MethodData<AdvancedComicBookFormat::Reference *(const QString &, const QStringList &)>(5, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 6, {{
            { QMetaType::QString, 7 }, { QMetaType::QStringList, 8 },
        }}),
        // Method 'swapReferences'
        QtMocHelpers::MethodData<void(QObject *, QObject *)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QObjectStar, 11 }, { QMetaType::QObjectStar, 12 },
        }}),
        // Method 'swapReferencesByIndex'
        QtMocHelpers::MethodData<void(int, int)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 }, { QMetaType::Int, 12 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'references'
        QtMocHelpers::PropertyData<QObjectList>(14, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'referenceIds'
        QtMocHelpers::PropertyData<QStringList>(16, QMetaType::QStringList, QMC::DefaultPropertyFlags, 0),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<References, qt_meta_tag_ZN23AdvancedComicBookFormat10ReferencesE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AdvancedComicBookFormat::References::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23AdvancedComicBookFormat10ReferencesE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23AdvancedComicBookFormat10ReferencesE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23AdvancedComicBookFormat10ReferencesE_t>.metaTypes,
    nullptr
} };

void AdvancedComicBookFormat::References::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<References *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->referencesChanged(); break;
        case 1: _t->referenceAdded((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        case 2: { AdvancedComicBookFormat::Reference* _r = _t->addReference((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<AdvancedComicBookFormat::Reference**>(_a[0]) = std::move(_r); }  break;
        case 3: { AdvancedComicBookFormat::Reference* _r = _t->addReference((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])));
            if (_a[0]) *reinterpret_cast<AdvancedComicBookFormat::Reference**>(_a[0]) = std::move(_r); }  break;
        case 4: _t->swapReferences((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[2]))); break;
        case 5: _t->swapReferencesByIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (References::*)()>(_a, &References::referencesChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (References::*)(QObject * )>(_a, &References::referenceAdded, 1))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QObjectList*>(_v) = _t->references(); break;
        case 1: *reinterpret_cast<QStringList*>(_v) = _t->referenceIds(); break;
        default: break;
        }
    }
}

const QMetaObject *AdvancedComicBookFormat::References::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AdvancedComicBookFormat::References::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23AdvancedComicBookFormat10ReferencesE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int AdvancedComicBookFormat::References::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void AdvancedComicBookFormat::References::referencesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void AdvancedComicBookFormat::References::referenceAdded(QObject * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
