/****************************************************************************
** Meta object code from reading C++ file 'CategoryEntriesModel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../mauikit-documents-4.0.2/src/code/cbz/code/CategoryEntriesModel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'CategoryEntriesModel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN20CategoryEntriesModelE_t {};
} // unnamed namespace

template <> constexpr inline auto CategoryEntriesModel::qt_create_metaobjectdata<qt_meta_tag_ZN20CategoryEntriesModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CategoryEntriesModel",
        "countChanged",
        "",
        "entryDataUpdated",
        "BookEntry*",
        "entry",
        "entryRemoved",
        "entryDataChanged",
        "entryRemove",
        "append",
        "Roles",
        "compareRole",
        "appendFakeBook",
        "book",
        "clear",
        "get",
        "index",
        "getBookEntry",
        "getEntry",
        "bookFromFile",
        "filename",
        "indexOfFile",
        "indexIsBook",
        "count",
        "UnknownRole",
        "FilenameRole",
        "FiletitleRole",
        "TitleRole",
        "SeriesRole",
        "SeriesNumbersRole",
        "SeriesVolumesRole",
        "AuthorRole",
        "PublisherRole",
        "CreatedRole",
        "LastOpenedTimeRole",
        "TotalPagesRole",
        "CurrentPageRole",
        "CategoryEntriesModelRole",
        "CategoryEntryCountRole",
        "ThumbnailRole",
        "DescriptionRole",
        "CommentRole",
        "TagsRole",
        "RatingRole",
        "GenreRole",
        "KeywordRole",
        "CharacterRole"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'countChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'entryDataUpdated'
        QtMocHelpers::SignalData<void(BookEntry *)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Signal 'entryRemoved'
        QtMocHelpers::SignalData<void(BookEntry *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'entryDataChanged'
        QtMocHelpers::SlotData<void(BookEntry *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'entryRemove'
        QtMocHelpers::SlotData<void(BookEntry *)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Method 'append'
        QtMocHelpers::MethodData<void(BookEntry *, enum Roles)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 }, { 0x80000000 | 10, 11 },
        }}),
        // Method 'append'
        QtMocHelpers::MethodData<void(BookEntry *)>(9, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Method 'appendFakeBook'
        QtMocHelpers::MethodData<void(QObject *, enum Roles)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QObjectStar, 13 }, { 0x80000000 | 10, 11 },
        }}),
        // Method 'appendFakeBook'
        QtMocHelpers::MethodData<void(QObject *)>(12, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QObjectStar, 13 },
        }}),
        // Method 'clear'
        QtMocHelpers::MethodData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'get'
        QtMocHelpers::MethodData<QObject *(int)>(15, 2, QMC::AccessPublic, QMetaType::QObjectStar, {{
            { QMetaType::Int, 16 },
        }}),
        // Method 'getBookEntry'
        QtMocHelpers::MethodData<BookEntry *(int)>(17, 2, QMC::AccessPublic, 0x80000000 | 4, {{
            { QMetaType::Int, 16 },
        }}),
        // Method 'getEntry'
        QtMocHelpers::MethodData<QObject *(int)>(18, 2, QMC::AccessPublic, QMetaType::QObjectStar, {{
            { QMetaType::Int, 16 },
        }}),
        // Method 'bookFromFile'
        QtMocHelpers::MethodData<QObject *(const QString &)>(19, 2, QMC::AccessPublic, QMetaType::QObjectStar, {{
            { QMetaType::QString, 20 },
        }}),
        // Method 'indexOfFile'
        QtMocHelpers::MethodData<int(const QString &)>(21, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 20 },
        }}),
        // Method 'indexIsBook'
        QtMocHelpers::MethodData<bool(int)>(22, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 16 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'count'
        QtMocHelpers::PropertyData<int>(23, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Roles'
        QtMocHelpers::EnumData<enum Roles>(10, 10, QMC::EnumFlags{}).add({
            {   24, Roles::UnknownRole },
            {   25, Roles::FilenameRole },
            {   26, Roles::FiletitleRole },
            {   27, Roles::TitleRole },
            {   28, Roles::SeriesRole },
            {   29, Roles::SeriesNumbersRole },
            {   30, Roles::SeriesVolumesRole },
            {   31, Roles::AuthorRole },
            {   32, Roles::PublisherRole },
            {   33, Roles::CreatedRole },
            {   34, Roles::LastOpenedTimeRole },
            {   35, Roles::TotalPagesRole },
            {   36, Roles::CurrentPageRole },
            {   37, Roles::CategoryEntriesModelRole },
            {   38, Roles::CategoryEntryCountRole },
            {   39, Roles::ThumbnailRole },
            {   40, Roles::DescriptionRole },
            {   41, Roles::CommentRole },
            {   42, Roles::TagsRole },
            {   43, Roles::RatingRole },
            {   44, Roles::GenreRole },
            {   45, Roles::KeywordRole },
            {   46, Roles::CharacterRole },
        }),
    };
    return QtMocHelpers::metaObjectData<CategoryEntriesModel, qt_meta_tag_ZN20CategoryEntriesModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject CategoryEntriesModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20CategoryEntriesModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20CategoryEntriesModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20CategoryEntriesModelE_t>.metaTypes,
    nullptr
} };

void CategoryEntriesModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CategoryEntriesModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->countChanged(); break;
        case 1: _t->entryDataUpdated((*reinterpret_cast<std::add_pointer_t<BookEntry*>>(_a[1]))); break;
        case 2: _t->entryRemoved((*reinterpret_cast<std::add_pointer_t<BookEntry*>>(_a[1]))); break;
        case 3: _t->entryDataChanged((*reinterpret_cast<std::add_pointer_t<BookEntry*>>(_a[1]))); break;
        case 4: _t->entryRemove((*reinterpret_cast<std::add_pointer_t<BookEntry*>>(_a[1]))); break;
        case 5: _t->append((*reinterpret_cast<std::add_pointer_t<BookEntry*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<enum Roles>>(_a[2]))); break;
        case 6: _t->append((*reinterpret_cast<std::add_pointer_t<BookEntry*>>(_a[1]))); break;
        case 7: _t->appendFakeBook((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<enum Roles>>(_a[2]))); break;
        case 8: _t->appendFakeBook((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        case 9: _t->clear(); break;
        case 10: { QObject* _r = _t->get((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QObject**>(_a[0]) = std::move(_r); }  break;
        case 11: { BookEntry* _r = _t->getBookEntry((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<BookEntry**>(_a[0]) = std::move(_r); }  break;
        case 12: { QObject* _r = _t->getEntry((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QObject**>(_a[0]) = std::move(_r); }  break;
        case 13: { QObject* _r = _t->bookFromFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QObject**>(_a[0]) = std::move(_r); }  break;
        case 14: { int _r = _t->indexOfFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 15: { bool _r = _t->indexIsBook((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (CategoryEntriesModel::*)()>(_a, &CategoryEntriesModel::countChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (CategoryEntriesModel::*)(BookEntry * )>(_a, &CategoryEntriesModel::entryDataUpdated, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (CategoryEntriesModel::*)(BookEntry * )>(_a, &CategoryEntriesModel::entryRemoved, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->count(); break;
        default: break;
        }
    }
}

const QMetaObject *CategoryEntriesModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CategoryEntriesModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20CategoryEntriesModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int CategoryEntriesModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 16;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void CategoryEntriesModel::countChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void CategoryEntriesModel::entryDataUpdated(BookEntry * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void CategoryEntriesModel::entryRemoved(BookEntry * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
