/****************************************************************************
** Meta object code from reading C++ file 'AcbfPage.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../../mauikit-documents-4.0.2/src/code/cbz/code/acbf/AcbfPage.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'AcbfPage.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN23AdvancedComicBookFormat4PageE_t {};
} // unnamed namespace

template <> constexpr inline auto AdvancedComicBookFormat::Page::qt_create_metaobjectdata<qt_meta_tag_ZN23AdvancedComicBookFormat4PageE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AdvancedComicBookFormat::Page",
        "idChanged",
        "",
        "bgcolorChanged",
        "transitionChanged",
        "titlesChanged",
        "imageHrefChanged",
        "textLayerAdded",
        "Textlayer*",
        "newTextlayer",
        "textLayerLanguagesChanged",
        "frameAdded",
        "Frame*",
        "newFrame",
        "framePointStringsChanged",
        "jumpAdded",
        "Jump*",
        "newJump",
        "jumpsChanged",
        "availableTransitions",
        "titleForAllLanguages",
        "title",
        "language",
        "setTitle",
        "textLayer",
        "addTextLayer",
        "removeTextLayer",
        "duplicateTextLayer",
        "languageFrom",
        "languageTo",
        "frame",
        "index",
        "removeFrame",
        "addFrame",
        "swapFrames",
        "swapThis",
        "withThis",
        "jump",
        "addJump",
        "pageIndex",
        "removeJump",
        "swapJumps",
        "id",
        "bgcolor",
        "transition",
        "imageHref",
        "textLayerLanguages",
        "framePointStrings",
        "jumps",
        "QObjectList"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'idChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'bgcolorChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'transitionChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'titlesChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'imageHrefChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'textLayerAdded'
        QtMocHelpers::SignalData<void(Textlayer *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Signal 'textLayerLanguagesChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'frameAdded'
        QtMocHelpers::SignalData<void(Frame *)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Signal 'framePointStringsChanged'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'jumpAdded'
        QtMocHelpers::SignalData<void(Jump *)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Signal 'jumpsChanged'
        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'availableTransitions'
        QtMocHelpers::MethodData<QStringList()>(19, 2, QMC::AccessPublic, QMetaType::QStringList),
        // Method 'titleForAllLanguages'
        QtMocHelpers::MethodData<QStringList() const>(20, 2, QMC::AccessPublic, QMetaType::QStringList),
        // Method 'title'
        QtMocHelpers::MethodData<QString(const QString &) const>(21, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 22 },
        }}),
        // Method 'title'
        QtMocHelpers::MethodData<QString() const>(21, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString),
        // Method 'setTitle'
        QtMocHelpers::MethodData<void(const QString &, const QString &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 21 }, { QMetaType::QString, 22 },
        }}),
        // Method 'setTitle'
        QtMocHelpers::MethodData<void(const QString &)>(23, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 21 },
        }}),
        // Method 'textLayer'
        QtMocHelpers::MethodData<Textlayer *(const QString &) const>(24, 2, QMC::AccessPublic, 0x80000000 | 8, {{
            { QMetaType::QString, 22 },
        }}),
        // Method 'textLayer'
        QtMocHelpers::MethodData<Textlayer *() const>(24, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 8),
        // Method 'addTextLayer'
        QtMocHelpers::MethodData<void(const QString &)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 22 },
        }}),
        // Method 'addTextLayer'
        QtMocHelpers::MethodData<void()>(25, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Method 'removeTextLayer'
        QtMocHelpers::MethodData<void(const QString &)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 22 },
        }}),
        // Method 'removeTextLayer'
        QtMocHelpers::MethodData<void()>(26, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Method 'duplicateTextLayer'
        QtMocHelpers::MethodData<void(const QString &, const QString &)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 28 }, { QMetaType::QString, 29 },
        }}),
        // Method 'duplicateTextLayer'
        QtMocHelpers::MethodData<void(const QString &)>(27, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 28 },
        }}),
        // Method 'frame'
        QtMocHelpers::MethodData<Frame *(int) const>(30, 2, QMC::AccessPublic, 0x80000000 | 12, {{
            { QMetaType::Int, 31 },
        }}),
        // Method 'removeFrame'
        QtMocHelpers::MethodData<void(int)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 31 },
        }}),
        // Method 'addFrame'
        QtMocHelpers::MethodData<void(int)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 31 },
        }}),
        // Method 'addFrame'
        QtMocHelpers::MethodData<void()>(33, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Method 'swapFrames'
        QtMocHelpers::MethodData<bool(int, int)>(34, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 35 }, { QMetaType::Int, 36 },
        }}),
        // Method 'jump'
        QtMocHelpers::MethodData<Jump *(int) const>(37, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::Int, 31 },
        }}),
        // Method 'addJump'
        QtMocHelpers::MethodData<void(int, int)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 39 }, { QMetaType::Int, 31 },
        }}),
        // Method 'addJump'
        QtMocHelpers::MethodData<void(int)>(38, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 39 },
        }}),
        // Method 'removeJump'
        QtMocHelpers::MethodData<void(int)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 31 },
        }}),
        // Method 'swapJumps'
        QtMocHelpers::MethodData<bool(int, int)>(41, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 35 }, { QMetaType::Int, 36 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'id'
        QtMocHelpers::PropertyData<QString>(42, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'bgcolor'
        QtMocHelpers::PropertyData<QString>(43, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'transition'
        QtMocHelpers::PropertyData<QString>(44, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'imageHref'
        QtMocHelpers::PropertyData<QString>(45, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'textLayerLanguages'
        QtMocHelpers::PropertyData<QStringList>(46, QMetaType::QStringList, QMC::DefaultPropertyFlags, 6),
        // property 'framePointStrings'
        QtMocHelpers::PropertyData<QStringList>(47, QMetaType::QStringList, QMC::DefaultPropertyFlags, 8),
        // property 'jumps'
        QtMocHelpers::PropertyData<QObjectList>(48, 0x80000000 | 49, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 10),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Page, qt_meta_tag_ZN23AdvancedComicBookFormat4PageE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AdvancedComicBookFormat::Page::staticMetaObject = { {
    QMetaObject::SuperData::link<InternalReferenceObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23AdvancedComicBookFormat4PageE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23AdvancedComicBookFormat4PageE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23AdvancedComicBookFormat4PageE_t>.metaTypes,
    nullptr
} };

void AdvancedComicBookFormat::Page::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Page *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->idChanged(); break;
        case 1: _t->bgcolorChanged(); break;
        case 2: _t->transitionChanged(); break;
        case 3: _t->titlesChanged(); break;
        case 4: _t->imageHrefChanged(); break;
        case 5: _t->textLayerAdded((*reinterpret_cast<std::add_pointer_t<Textlayer*>>(_a[1]))); break;
        case 6: _t->textLayerLanguagesChanged(); break;
        case 7: _t->frameAdded((*reinterpret_cast<std::add_pointer_t<Frame*>>(_a[1]))); break;
        case 8: _t->framePointStringsChanged(); break;
        case 9: _t->jumpAdded((*reinterpret_cast<std::add_pointer_t<Jump*>>(_a[1]))); break;
        case 10: _t->jumpsChanged(); break;
        case 11: { QStringList _r = _t->availableTransitions();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 12: { QStringList _r = _t->titleForAllLanguages();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 13: { QString _r = _t->title((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 14: { QString _r = _t->title();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 15: _t->setTitle((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 16: _t->setTitle((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 17: { Textlayer* _r = _t->textLayer((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Textlayer**>(_a[0]) = std::move(_r); }  break;
        case 18: { Textlayer* _r = _t->textLayer();
            if (_a[0]) *reinterpret_cast<Textlayer**>(_a[0]) = std::move(_r); }  break;
        case 19: _t->addTextLayer((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 20: _t->addTextLayer(); break;
        case 21: _t->removeTextLayer((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 22: _t->removeTextLayer(); break;
        case 23: _t->duplicateTextLayer((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 24: _t->duplicateTextLayer((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 25: { Frame* _r = _t->frame((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Frame**>(_a[0]) = std::move(_r); }  break;
        case 26: _t->removeFrame((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 27: _t->addFrame((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 28: _t->addFrame(); break;
        case 29: { bool _r = _t->swapFrames((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 30: { Jump* _r = _t->jump((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Jump**>(_a[0]) = std::move(_r); }  break;
        case 31: _t->addJump((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 32: _t->addJump((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 33: _t->removeJump((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 34: { bool _r = _t->swapJumps((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Page::*)()>(_a, &Page::idChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Page::*)()>(_a, &Page::bgcolorChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Page::*)()>(_a, &Page::transitionChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Page::*)()>(_a, &Page::titlesChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Page::*)()>(_a, &Page::imageHrefChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Page::*)(Textlayer * )>(_a, &Page::textLayerAdded, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Page::*)()>(_a, &Page::textLayerLanguagesChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Page::*)(Frame * )>(_a, &Page::frameAdded, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Page::*)()>(_a, &Page::framePointStringsChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Page::*)(Jump * )>(_a, &Page::jumpAdded, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Page::*)()>(_a, &Page::jumpsChanged, 10))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->id(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->bgcolor(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->transition(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->imageHref(); break;
        case 4: *reinterpret_cast<QStringList*>(_v) = _t->textLayerLanguages(); break;
        case 5: *reinterpret_cast<QStringList*>(_v) = _t->framePointStrings(); break;
        case 6: *reinterpret_cast<QObjectList*>(_v) = _t->jumps(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setId(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setBgcolor(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setTransition(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setImageHref(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *AdvancedComicBookFormat::Page::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AdvancedComicBookFormat::Page::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23AdvancedComicBookFormat4PageE_t>.strings))
        return static_cast<void*>(this);
    return InternalReferenceObject::qt_metacast(_clname);
}

int AdvancedComicBookFormat::Page::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = InternalReferenceObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 35)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 35;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 35)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 35;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void AdvancedComicBookFormat::Page::idChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void AdvancedComicBookFormat::Page::bgcolorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void AdvancedComicBookFormat::Page::transitionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void AdvancedComicBookFormat::Page::titlesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void AdvancedComicBookFormat::Page::imageHrefChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void AdvancedComicBookFormat::Page::textLayerAdded(Textlayer * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void AdvancedComicBookFormat::Page::textLayerLanguagesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void AdvancedComicBookFormat::Page::frameAdded(Frame * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void AdvancedComicBookFormat::Page::framePointStringsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void AdvancedComicBookFormat::Page::jumpAdded(Jump * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void AdvancedComicBookFormat::Page::jumpsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}
QT_WARNING_POP
