/****************************************************************************
** Meta object code from reading C++ file 'AcbfTextarea.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../../mauikit-documents-4.0.2/src/code/cbz/code/acbf/AcbfTextarea.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'AcbfTextarea.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN23AdvancedComicBookFormat8TextareaE_t {};
} // unnamed namespace

template <> constexpr inline auto AdvancedComicBookFormat::Textarea::qt_create_metaobjectdata<qt_meta_tag_ZN23AdvancedComicBookFormat8TextareaE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AdvancedComicBookFormat::Textarea",
        "idChanged",
        "",
        "pointCountChanged",
        "boundsChanged",
        "bgcolorChanged",
        "textRotationChanged",
        "typeChanged",
        "invertedChanged",
        "transparentChanged",
        "paragraphsChanged",
        "availableTypes",
        "point",
        "QPoint",
        "index",
        "pointIndex",
        "addPoint",
        "removePoint",
        "setPointsFromRect",
        "topLeft",
        "bottomRight",
        "id",
        "bgcolor",
        "pointCount",
        "bounds",
        "QRect",
        "textRotation",
        "type",
        "inverted",
        "transparent",
        "paragraphs",
        "points",
        "QVariantList"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'idChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pointCountChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'boundsChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'bgcolorChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'textRotationChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'typeChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'invertedChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'transparentChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'paragraphsChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'availableTypes'
        QtMocHelpers::MethodData<QStringList()>(11, 2, QMC::AccessPublic, QMetaType::QStringList),
        // Method 'point'
        QtMocHelpers::MethodData<QPoint(int) const>(12, 2, QMC::AccessPublic, 0x80000000 | 13, {{
            { QMetaType::Int, 14 },
        }}),
        // Method 'pointIndex'
        QtMocHelpers::MethodData<int(const QPoint &) const>(15, 2, QMC::AccessPublic, QMetaType::Int, {{
            { 0x80000000 | 13, 12 },
        }}),
        // Method 'addPoint'
        QtMocHelpers::MethodData<void(const QPoint &, int)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 12 }, { QMetaType::Int, 14 },
        }}),
        // Method 'addPoint'
        QtMocHelpers::MethodData<void(const QPoint &)>(16, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 13, 12 },
        }}),
        // Method 'removePoint'
        QtMocHelpers::MethodData<void(const QPoint &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 12 },
        }}),
        // Method 'setPointsFromRect'
        QtMocHelpers::MethodData<void(const QPoint &, const QPoint &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 19 }, { 0x80000000 | 13, 20 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'id'
        QtMocHelpers::PropertyData<QString>(21, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'bgcolor'
        QtMocHelpers::PropertyData<QString>(22, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'pointCount'
        QtMocHelpers::PropertyData<int>(23, QMetaType::Int, QMC::DefaultPropertyFlags, 1),
        // property 'bounds'
        QtMocHelpers::PropertyData<QRect>(24, 0x80000000 | 25, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'textRotation'
        QtMocHelpers::PropertyData<int>(26, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'type'
        QtMocHelpers::PropertyData<QString>(27, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'inverted'
        QtMocHelpers::PropertyData<bool>(28, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'transparent'
        QtMocHelpers::PropertyData<bool>(29, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'paragraphs'
        QtMocHelpers::PropertyData<QStringList>(30, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'points'
        QtMocHelpers::PropertyData<QVariantList>(31, 0x80000000 | 32, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Textarea, qt_meta_tag_ZN23AdvancedComicBookFormat8TextareaE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AdvancedComicBookFormat::Textarea::staticMetaObject = { {
    QMetaObject::SuperData::link<InternalReferenceObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23AdvancedComicBookFormat8TextareaE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23AdvancedComicBookFormat8TextareaE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23AdvancedComicBookFormat8TextareaE_t>.metaTypes,
    nullptr
} };

void AdvancedComicBookFormat::Textarea::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Textarea *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->idChanged(); break;
        case 1: _t->pointCountChanged(); break;
        case 2: _t->boundsChanged(); break;
        case 3: _t->bgcolorChanged(); break;
        case 4: _t->textRotationChanged(); break;
        case 5: _t->typeChanged(); break;
        case 6: _t->invertedChanged(); break;
        case 7: _t->transparentChanged(); break;
        case 8: _t->paragraphsChanged(); break;
        case 9: { QStringList _r = _t->availableTypes();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 10: { QPoint _r = _t->point((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QPoint*>(_a[0]) = std::move(_r); }  break;
        case 11: { int _r = _t->pointIndex((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 12: _t->addPoint((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 13: _t->addPoint((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 14: _t->removePoint((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 15: _t->setPointsFromRect((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Textarea::*)()>(_a, &Textarea::idChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Textarea::*)()>(_a, &Textarea::pointCountChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Textarea::*)()>(_a, &Textarea::boundsChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Textarea::*)()>(_a, &Textarea::bgcolorChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Textarea::*)()>(_a, &Textarea::textRotationChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Textarea::*)()>(_a, &Textarea::typeChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Textarea::*)()>(_a, &Textarea::invertedChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Textarea::*)()>(_a, &Textarea::transparentChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Textarea::*)()>(_a, &Textarea::paragraphsChanged, 8))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->id(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->bgcolor(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->pointCount(); break;
        case 3: *reinterpret_cast<QRect*>(_v) = _t->bounds(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->textRotation(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->type(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->inverted(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->transparent(); break;
        case 8: *reinterpret_cast<QStringList*>(_v) = _t->paragraphs(); break;
        case 9: *reinterpret_cast<QVariantList*>(_v) = _t->points(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setId(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setBgcolor(*reinterpret_cast<QString*>(_v)); break;
        case 4: _t->setTextRotation(*reinterpret_cast<int*>(_v)); break;
        case 5: _t->setType(*reinterpret_cast<QString*>(_v)); break;
        case 6: _t->setInverted(*reinterpret_cast<bool*>(_v)); break;
        case 7: _t->setTransparent(*reinterpret_cast<bool*>(_v)); break;
        case 8: _t->setParagraphs(*reinterpret_cast<QStringList*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *AdvancedComicBookFormat::Textarea::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AdvancedComicBookFormat::Textarea::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23AdvancedComicBookFormat8TextareaE_t>.strings))
        return static_cast<void*>(this);
    return InternalReferenceObject::qt_metacast(_clname);
}

int AdvancedComicBookFormat::Textarea::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = InternalReferenceObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 16;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void AdvancedComicBookFormat::Textarea::idChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void AdvancedComicBookFormat::Textarea::pointCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void AdvancedComicBookFormat::Textarea::boundsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void AdvancedComicBookFormat::Textarea::bgcolorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void AdvancedComicBookFormat::Textarea::textRotationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void AdvancedComicBookFormat::Textarea::typeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void AdvancedComicBookFormat::Textarea::invertedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void AdvancedComicBookFormat::Textarea::transparentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void AdvancedComicBookFormat::Textarea::paragraphsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
