/****************************************************************************
** Meta object code from reading C++ file 'AcbfDocument.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../../mauikit-documents-4.0.2/src/code/cbz/code/acbf/AcbfDocument.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'AcbfDocument.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN23AdvancedComicBookFormat8DocumentE_t {};
} // unnamed namespace

template <> constexpr inline auto AdvancedComicBookFormat::Document::qt_create_metaobjectdata<qt_meta_tag_ZN23AdvancedComicBookFormat8DocumentE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AdvancedComicBookFormat::Document",
        "metaDataChanged",
        "",
        "bodyChanged",
        "referencesChanged",
        "dataChanged",
        "stylesheetChanged",
        "metaData",
        "AdvancedComicBookFormat::Metadata*",
        "body",
        "AdvancedComicBookFormat::Body*",
        "references",
        "AdvancedComicBookFormat::References*",
        "data",
        "AdvancedComicBookFormat::Data*",
        "styleSheet",
        "AdvancedComicBookFormat::StyleSheet*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'metaDataChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'bodyChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'referencesChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dataChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'stylesheetChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'metaData'
        QtMocHelpers::PropertyData<AdvancedComicBookFormat::Metadata*>(7, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'body'
        QtMocHelpers::PropertyData<AdvancedComicBookFormat::Body*>(9, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'references'
        QtMocHelpers::PropertyData<AdvancedComicBookFormat::References*>(11, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'data'
        QtMocHelpers::PropertyData<AdvancedComicBookFormat::Data*>(13, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 3),
        // property 'styleSheet'
        QtMocHelpers::PropertyData<AdvancedComicBookFormat::StyleSheet*>(15, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 4),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Document, qt_meta_tag_ZN23AdvancedComicBookFormat8DocumentE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AdvancedComicBookFormat::Document::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23AdvancedComicBookFormat8DocumentE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23AdvancedComicBookFormat8DocumentE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23AdvancedComicBookFormat8DocumentE_t>.metaTypes,
    nullptr
} };

void AdvancedComicBookFormat::Document::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Document *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->metaDataChanged(); break;
        case 1: _t->bodyChanged(); break;
        case 2: _t->referencesChanged(); break;
        case 3: _t->dataChanged(); break;
        case 4: _t->stylesheetChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Document::*)()>(_a, &Document::metaDataChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Document::*)()>(_a, &Document::bodyChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Document::*)()>(_a, &Document::referencesChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Document::*)()>(_a, &Document::dataChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Document::*)()>(_a, &Document::stylesheetChanged, 4))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< AdvancedComicBookFormat::Body* >(); break;
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< AdvancedComicBookFormat::Data* >(); break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< AdvancedComicBookFormat::Metadata* >(); break;
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< AdvancedComicBookFormat::References* >(); break;
        case 4:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< AdvancedComicBookFormat::StyleSheet* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<AdvancedComicBookFormat::Metadata**>(_v) = _t->metaData(); break;
        case 1: *reinterpret_cast<AdvancedComicBookFormat::Body**>(_v) = _t->body(); break;
        case 2: *reinterpret_cast<AdvancedComicBookFormat::References**>(_v) = _t->references(); break;
        case 3: *reinterpret_cast<AdvancedComicBookFormat::Data**>(_v) = _t->data(); break;
        case 4: *reinterpret_cast<AdvancedComicBookFormat::StyleSheet**>(_v) = _t->styleSheet(); break;
        default: break;
        }
    }
}

const QMetaObject *AdvancedComicBookFormat::Document::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AdvancedComicBookFormat::Document::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23AdvancedComicBookFormat8DocumentE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int AdvancedComicBookFormat::Document::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void AdvancedComicBookFormat::Document::metaDataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void AdvancedComicBookFormat::Document::bodyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void AdvancedComicBookFormat::Document::referencesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void AdvancedComicBookFormat::Document::dataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void AdvancedComicBookFormat::Document::stylesheetChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
